@@ -24,7 +24,6 @@ def to_tensor(x, device, dtype=torch.float32):
         return torch.tensor(x).to(device=device, dtype=dtype)
 
 
-
 def img_to_tensor(img: Image, batch_size, device, half_precision: bool, shift_range=False, unsqueeze=False):
     if img is None:
         return None
@@ -91,6 +90,14 @@ def latent_samples_to_images(context: Context, samples):
     return images
 
 
+@torch.no_grad()
+def diffusers_latent_samples_to_images(context: Context, samples):
+    samples, model = samples
+    samples = model.decode_latents(samples)
+
+    return model.numpy_to_pil(samples)
+
+
 def tensor_to_bitmap(tensor):
     "Generates a grayscale bitmap from the given tensor"
 
